pub enum NdkError {
Show 15 variants
SdkNotFound,
NdkNotFound,
ToolchainBinaryNotFound {
toolchain_path: PathBuf,
gnu_bin: String,
llvm_bin: String,
},
PathNotFound(PathBuf),
CmdNotFound(String),
BuildToolsNotFound,
NoPlatformFound,
PlatformNotFound(u32),
UnsupportedTarget,
UnsupportedHost(String),
Io(IoError),
IoPathError(IoError, PathBuf),
InvalidSemver,
CmdFailed(Command),
Serialize(DeError),
}
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
The lower-level source of this error, if any. Read more
🔬 This is a nightly-only experimental API. (backtrace)
Returns a stack backtrace, if available, of where this error occurred. Read more
👎 Deprecated since 1.42.0:
use the Display impl or to_string()
👎 Deprecated since 1.33.0:
replaced by Error::source, which can support downcasting
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.