pub enum StripConfig {
Default,
Strip,
Split,
}Expand description
The options for how to treat debug symbols that are present in any .so
files that are added to the APK.
Using strip
or split-debuginfo
in your cargo manifest(s) may cause debug symbols to not be present in a
.so, which would cause these options to do nothing.
Variants
Default
Does not treat debug symbols specially
Strip
Removes debug symbols from the library before copying it into the APK
Split
Splits the library into into an ELF (.so) and DWARF (.dwarf). Only the
.so is copied into the APK